==> ZZ-Source-Code-karing-1.2.4.869.zip: karing-1.2.4.869/README_ru.md <==
<h1 align="center">
  <img src="./README_assets/img/mascot.jpg" alt="Karing" width="256" />
  <br>
  Karing - Утилита прокси с простым и мощным интерфейсом
  <br>
</h1>

<h3 align="center">
Графический интерфейс <a href="https://github.com/SagerNet/sing-box">singbox</a> на основе <a href="https://github.com/flutter/flutter">flutter</a>.
</h3>

[Английский](./README.md)  | [Китайский](./README_cn.md) | Русский | [Персидский](./README_fa.md)
### Примечание. Компания Karing не открывала ни одного канала о компании Karing ни на одной видеоплатформе.
## Особенности
- Совместим с Clash, V2ray/V2fly, Sing-box, Shadowsocks, Sub, подписками на GitHub.
- Полная поддержка конфигурации `clash`, частичная поддержка конфигурации `clash.meta`.
- Простой пользовательский интерфейс и поддержка настраиваемого цветового оформления.
- Встроенная поддержка ядра [singbox](https://github.com/SagerNet/sing-box).
- Настройка системного прокси и защита.
- Планы поддержки всех платформ.

## Продвижение
<details>
<summary>Продвижение

[NETZ —— ISP in Russia](https://netz.run)

- Высокопроизводственный зарубежный VPN, бесплатное испытание, поддержка протокола Trojan.
- Бесплатное испытание и покупка (без регистрации): [Telegram bot](https://t.me/netzrun_bot?start=ref_karing)


[List of other ISPs](https://1.x31415926.top/ru.html)



### VPN Providers Collaboration Announcement
- 👉[Contact information and forms of cooperation](https://karing.app/blog/isp/cooperation#for-vpn-providers-from-other-regions)👈

</summary>
</details>

## Системные требования
- Windows >= 10 (только 64-битные)
- Android >= 8 (arm64-v8a, armeabi-v7a)
- IOS >= 15
- MacOS >= 12
- TvOS >= 17

## Установка
- **IOS/MacOS/TvOS AppStore**: (Поиск по ключевым словам: karing vpn)
  - https://apps.apple.com/us/app/karing/id6472431552
- **IOS/MacOS/TvOS TestFlight**:
  - https://testflight.apple.com/join/RLU59OsJ
- **Android**:
  - https://github.com/KaringX/karing/releases/latest
  - APKPure https://apkpure.com/p/com.nebula.karing
  - Amazon AppStore https://www.amazon.com/gp/product/B0DJSQDDM8
  - [gh-proxy of android backup](https://dot.karing.app/client.html?p=android)
- **Windows**:
  - https://github.com/KaringX/karing/releases/latest
  - [gh-proxy of win64 backup](https://dot.karing.app/client.html?p=windows)

### ЧаВо

> [FAQ|en](https://karing.app/en/faq/)

## Планы
- Платформы, которые будут поддержаны:
  - linux | [linglong](https://linglong.dev/)
- Глобализация (многоязычность)
  - Если вы готовы сотрудничать с нами для поддержки глобализации Karing, отправьте электронное письмо на bdluking@gmail.com для участия

## Скриншоты (версия для Windows)

<div align="center">
  <img src="./README_assets/demo/home.png" alt="demo1" width="50%" />
  </br></br>
  <img src="./README_assets/demo/select_server.png" alt="demo2" width="50%" />
    </br></br>
  <img src="./README_assets/demo/connections.png" alt="demo3" width="50%" />
  </br></br>
  <img src="./README_assets/demo/setting.png" alt="demo4" width="50%" />
  </br></br>
  <img src="./README_assets/demo/routing_group.png" alt="demo5" width="50%" />
  </br></br>
  <img src="./README_assets/demo/add_profile_link.png" alt="demo6" width="50%" />
</div>

## Вклад
[Добро пожаловать к сообщению об ошибке!](https://github.com/KaringX/karing/issues)

## Donate
![donate](./README_assets/img/donate-usdt.jpg)

## Projects 

### Признательность: Karing был основан или вдохновлен следующими проектами и так далее:

- [flutter](https://flutter.dev/): облегчает и ускоряет создание красивых приложений для мобильных устройств и не только.
- [singbox](https://sing-box.sagernet.org/): универсальная платформа прокси.
- [Meta-Docs](https://wiki.metacubex.one/config/): Clash.Meta документация

### Karing Team:
- [Karing](https://karing.app): https://karing.app
- [Clash Mi](https://clashmi.app/): https://clashmi.app/
- [sing-poet](https://github.com/KaringX/sing-poet)

==> ZZ-Source-Code-karing-1.2.9.1210.zip: karing-1.2.9.1210/README_ru.md <==
<h1 align="center">
  <img src="./README_assets/img/mascot.jpg" alt="Karing" width="256" />
  <br>
  Karing - Утилита прокси с простым и мощным интерфейсом
  <br>
</h1>

<h3 align="center">
Графический интерфейс <a href="https://github.com/SagerNet/sing-box">singbox</a> на основе <a href="https://github.com/flutter/flutter">flutter</a>.
</h3>

[Английский](./README.md)  | [Китайский](./README_cn.md) | Русский | [Персидский](./README_fa.md)
### Примечание. Компания Karing не открывала ни одного канала о компании Karing ни на одной видеоплатформе.
## Особенности
- Совместим с Clash, V2ray/V2fly, Sing-box, Shadowsocks, Sub, подписками на GitHub.
- Полная поддержка конфигурации `clash`, частичная поддержка конфигурации `clash.meta`.
- Простой пользовательский интерфейс и поддержка настраиваемого цветового оформления.
- Встроенная поддержка ядра [singbox](https://github.com/SagerNet/sing-box).
- Настройка системного прокси и защита.
- Планы поддержки всех платформ.

## Продвижение
<details>
<summary>Продвижение

[NETZ —— ISP in Russia](https://netz.run)

- Высокопроизводственный зарубежный VPN, бесплатное испытание, поддержка протокола Trojan.
- Бесплатное испытание и покупка (без регистрации): [Telegram bot](https://t.me/netzrun_bot?start=ref_karing)


[List of other ISPs](https://1.x31415926.top/ru.html)



### VPN Providers Collaboration Announcement
- 👉[Contact information and forms of cooperation](https://karing.app/blog/isp/cooperation#for-vpn-providers-from-other-regions)👈

</summary>
</details>

## Системные требования
- Windows >= 10 (только 64-битные)
- Android >= 8 (arm64-v8a, armeabi-v7a)
- Linux (только 64-битные)
- IOS >= 15
- MacOS >= 12 (Intel, Apple Silicon)
- TvOS >= 17

## Установка
- **IOS/TvOS AppStore**: (Поиск по ключевым словам: karing vpn)
  - https://apps.apple.com/us/app/karing/id6472431552
- **IOS/TvOS TestFlight**:
  - https://testflight.apple.com/join/RLU59OsJ
- **Android**:
  - [https://karing.app/download](https://karing.app/download)
  - https://github.com/KaringX/karing/releases/latest
  - APKPure https://apkpure.com/p/com.nebula.karing
  - Amazon AppStore https://www.amazon.com/gp/product/B0DJSQDDM8

- **Windows/Macos/Linux**:
  - [https://karing.app/download](https://karing.app/download)
  - https://github.com/KaringX/karing/releases/latest

### ЧаВо

> [FAQ|en](https://karing.app/en/faq/)

## Планы
- Платформы, которые будут поддержаны:
  - linux | [linglong](https://linglong.dev/)
- Глобализация (многоязычность)
  - Если вы готовы сотрудничать с нами для поддержки глобализации Karing, отправьте электронное письмо на bdluking@gmail.com для участия

## Скриншоты (версия для Windows)

<div align="center">
  <img src="./README_assets/demo/home.png" alt="demo1" width="50%" />
  </br></br>
  <img src="./README_assets/demo/select_server.png" alt="demo2" width="50%" />
    </br></br>
  <img src="./README_assets/demo/connections.png" alt="demo3" width="50%" />
  </br></br>
  <img src="./README_assets/demo/setting.png" alt="demo4" width="50%" />
  </br></br>
  <img src="./README_assets/demo/routing_group.png" alt="demo5" width="50%" />
  </br></br>
  <img src="./README_assets/demo/add_profile_link.png" alt="demo6" width="50%" />
</div>

## Вклад
[Добро пожаловать к сообщению об ошибке!](https://github.com/KaringX/karing/issues)

## Donate
![donate](./README_assets/img/donate-usdt.jpg)

## Projects 

### Признательность: Karing был основан или вдохновлен следующими проектами и так далее:

- [flutter](https://flutter.dev/): облегчает и ускоряет создание красивых приложений для мобильных устройств и не только.
- [singbox](https://sing-box.sagernet.org/): универсальная платформа прокси.
- [Meta-Docs](https://wiki.metacubex.one/config/): Clash.Meta документация

### Karing Team:
- [Karing](https://karing.app): https://karing.app
- [Clash Mi](https://clashmi.app/): https://clashmi.app/
- [sing-poet](https://github.com/KaringX/sing-poet)
